**Purpose**:
The purpose of this document is to explain the core concepts / terminology of things seen in Veeam Backup & Replication from a relatively high-level.  It's more of a quick-reference guide than a formal education.

## Core Terminology:
### Backup Proxy
A backup "proxy" simply refers to a machine that is running the "**Veeam Backup Transport** agent on it.  The Veeam Backup & Replication server installs a proxy onto itself, but it also deploys proxies onto workstations, servers, and hypervisors.  These proxies are how the "Veeam Backup & Replication Console" interacts with the devices and performs backups and restores.
### Service Provider
Service Providers are not the same as cloud storage providers such as Backblaze B2, Amazon S3, etc.  Service Providers are Veeam "partners" who manage, maintain, and deploy Veeam backup appliances at client environments, as well as providing support to clients within the Veeam ecosystem.  You can also use Service Providers as a cloud backup destination in Veeam Backup & Replication for off-site backups.
### Backup Jobs
Backup jobs take many forms, but the most common are explained in more detail below.  Note that this is not an exhaustive list of the different kinds of backup jobs, just the ones I am currently most familiar with.

- **Backup**: This is the simplest of the backup job options.  A "Backup" backup job will take a backup of a workstation, server, File Server, specific local files and folders on a device, or a GuestVM running in a hypervisor such as Hyper-V, VMWare ESXi, Nutanix, or ProxmoxVE.  (*At the time of writing, these are the only hypervisors supported by Veeam Backup & Replication*).    
- **Backup Copy**: 
    - This is when you make a copy of backup data stored on the Veeam server, and send it somewhere else, such as an off-site "Service Provider" such as Veeam partners.  
    - You can also send backup copies to local drives, SMB network shares, NFS shares, File Servers, pretty much anywhere you can send normal backups, but with the key difference being the data is originating from the Veeam backup server itself instead of the original server/VM.
- **SureBackup**: This is where things get a little more complex.  SureBackup is where you effectively "Verify" your backups by spinning them up inside of a lab environment.  While they are spun up, they are checked to see if they fully boot, they can have antivirus scans, ransomware scans, custom scripts executed, and validate the integrity of the backups. The general core components are listed below:
    - **Virtual Lab**: The virtual lab is a virtual machine environment that you set up for Veeam to leverage to spin up backups on a hypervisor that you configure, such as a remote Hyper-V server in the same building, or perhaps if you have Hyper-V locally installed on the same server as Veeam itself, you would configure the virtual lab's hypervisor to point to `127.0.0.1` or `localhost`.
        - The virtual lab will have its own unique virtual networking for the VMs to communicate on, so they don't conflict with the production servers/VMs.
    - **Application Groups**: Application groups are defined groups of devices that need to be running when the backups are being validated.  For example, in my homelab, I have an application group named `Domain Controllers`, and I put `LAB-DC-01` and `LAB-DC-02` into that application group.  I use this as the application group associated with the Virtual Lab because most of my services are authenticated with Active Directory, and if the DCs were missing during backup verification, a variety of issues would ensue.  When the Backup Verification Lab (Virtual Lab) is launched on the targeted hypervisor, it spins up the application group devices from backups first, ensuring they are running and functional, before the virtual lab starts verifying backup objects designated in the "Linked Jobs", seen in the next section.
    - **Linked Jobs**: These are the "Backup Jobs" you want to verify in in the virtual lab mentioned above.  If you have a large backup job with a bunch of machines you don't want verified, you can configure "Exclusions" in the SureBackup job settings to exclude those objects/devices from verification.
### Replication
As the name states, Veeam Backup & Replication can also handle replicating Servers/VMs from either their original locations or from a recent backup and push them into a hypervisor for rapid failover/failback functionality.  Very useful for workloads that need to be spun up nearly immediately due to strict RTO requirements.  There are some additional notes regarding replication seen below.
    - **Replication Restore Points**: Similar to backups, replicas can have multiple restore points associated with them, so you have more than one option when spinning up a replica in a hypervisor.  
    !!! warning "Orchestrate Replication via Veeam, not the Hypervisor"
        You want to coordinate anything replication-wise directly in Veeam Backup & Replication, not directly on the hypervisor itself.  While you can do this, it is not only slower, but does not give you the option to failback replicas back into production if you spin up a replica directly on its hypervisor.